<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_TW">
<context>
    <name></name>
    <message>
        <source>Delete</source>
        <translation type="vanished">刪除</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation type="vanished">全螢幕</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation type="vanished">幻燈片秀</translation>
    </message>
    <message>
        <source>Export</source>
        <translation type="vanished">匯出照片</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation type="vanished">複製</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation type="vanished">收藏</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation type="vanished">順時針旋轉</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation type="vanished">逆時針旋轉</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation type="vanished">設為桌布</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation type="vanished">在檔案管理器中顯示</translation>
    </message>
    <message>
        <source>Photo info</source>
        <translation type="vanished">照片訊息</translation>
    </message>
    <message>
        <source>Video info</source>
        <translation type="vanished">影片訊息</translation>
    </message>
    <message>
        <source>Restore</source>
        <translation type="vanished">復原</translation>
    </message>
</context>
<context>
    <name>AlbumCreateDialog</name>
    <message>
        <source>Unnamed</source>
        <translation>未命名相簿</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>取消</translation>
    </message>
    <message>
        <source>Create</source>
        <translation>建立</translation>
    </message>
    <message>
        <source>New Album</source>
        <translation>新增相簿</translation>
    </message>
</context>
<context>
    <name>AlbumDeleteDialog</name>
    <message>
        <source>Cancel</source>
        <translation>取消</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>刪除</translation>
    </message>
    <message>
        <source>Are you sure you want to delete this album?</source>
        <translation>是否刪除此相簿？</translation>
    </message>
</context>
<context>
    <name>AlbumLeftTabItem</name>
    <message>
        <source>Trash</source>
        <translation>垃圾桶</translation>
    </message>
    <message>
        <source>Favorites</source>
        <translation>我的最愛</translation>
    </message>
    <message>
        <source>Import</source>
        <translation>匯入</translation>
    </message>
</context>
<context>
    <name>AlbumView</name>
    <message>
        <source>Trash</source>
        <translation>垃圾桶</translation>
    </message>
    <message>
        <source>Favorites</source>
        <translation>我的最愛</translation>
    </message>
    <message>
        <source>Or drag photos here</source>
        <translation>或拖曳照片至此</translation>
    </message>
    <message>
        <source>Import All</source>
        <translation>全部匯入</translation>
    </message>
    <message>
        <source>Import to:</source>
        <translation>匯入至：</translation>
    </message>
    <message>
        <source>Import</source>
        <translation>匯入</translation>
    </message>
    <message>
        <source>System Disk</source>
        <translation>系統磁碟</translation>
    </message>
    <message>
        <source>Gallery</source>
        <translation>照片庫</translation>
    </message>
    <message>
        <source>Disk is busy, cannot eject now</source>
        <translation>磁碟忙碌中，目前無法退出</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>確定</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>建立相簿</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>取消</translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation>忽略</translation>
    </message>
    <message>
        <source>Loading...</source>
        <translation>正在載入，請稍候...</translation>
    </message>
    <message>
        <source>The files will be permanently deleted after the days shown on them</source>
        <translation>文件在刪除前會顯示剩餘天數，之後將永久刪除</translation>
    </message>
    <message>
        <source>Image classification</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Application</name>
    <message>
        <source>Album</source>
        <translation>相簿</translation>
    </message>
</context>
<context>
    <name>CExportImageDialog</name>
    <message>
        <source>Cancel</source>
        <translation>取消</translation>
    </message>
    <message>
        <source>Replace</source>
        <translation>取代</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>匯出</translation>
    </message>
    <message>
        <source>Pictures</source>
        <translation>圖片</translation>
    </message>
    <message>
        <source>Documents</source>
        <translation>文件</translation>
    </message>
    <message>
        <source>Downloads</source>
        <translation>下載</translation>
    </message>
    <message>
        <source>Desktop</source>
        <translation>桌面</translation>
    </message>
    <message>
        <source>Videos</source>
        <translation>影片</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>音樂</translation>
    </message>
    <message>
        <source>Name:</source>
        <translation>名稱：</translation>
    </message>
    <message>
        <source>Save to:</source>
        <translation>儲存至：</translation>
    </message>
    <message>
        <source>Format:</source>
        <translation>格式：</translation>
    </message>
    <message>
        <source>Quality:</source>
        <translation>品質：</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>儲存</translation>
    </message>
    <message>
        <source>gif</source>
        <translation>gif</translation>
    </message>
    <message>
        <source>Select other directories</source>
        <translation>選擇其他目錄</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>確定</translation>
    </message>
    <message>
        <source>File name cannot be empty</source>
        <translation>檔名不能空白</translation>
    </message>
    <message>
        <source>already exists. Do you want to replace it?</source>
        <translation>已存在，是否取代？</translation>
    </message>
</context>
<context>
    <name>DBManager</name>
    <message>
        <source>Screen Capture</source>
        <translation>截圖錄屏</translation>
    </message>
    <message>
        <source>Camera</source>
        <translation>相機</translation>
    </message>
    <message>
        <source>Draw</source>
        <translation>畫板</translation>
    </message>
    <message>
        <source>(copy)</source>
        <translation>(副本)</translation>
    </message>
</context>
<context>
    <name>DeepinStorage</name>
    <message>
        <source>%1 Drive</source>
        <translation>%1 磁碟機</translation>
    </message>
    <message>
        <source>Blank %1 Disc</source>
        <translation>空白 %1 光碟</translation>
    </message>
    <message>
        <source>%1 Encrypted</source>
        <translation>已加密 %1</translation>
    </message>
    <message>
        <source>%1 Volume</source>
        <translation>%1 磁碟區</translation>
    </message>
</context>
<context>
    <name>Exporter</name>
    <message>
        <source>Save</source>
        <translation>儲存</translation>
    </message>
    <message>
        <source>Export Photos</source>
        <translation>匯出照片</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>取消</translation>
    </message>
</context>
<context>
    <name>ImageEngineApi</name>
    <message>
        <source>Deleting...</source>
        <translation>正在刪除...</translation>
    </message>
    <message>
        <source>Restoring...</source>
        <translation>正在復原...</translation>
    </message>
    <message>
        <source>Classifying...</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ImgDeleteDialog</name>
    <message>
        <source>Cancel</source>
        <translation>取消</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>刪除</translation>
    </message>
    <message>
        <source>Are you sure you want to permanently delete this file?</source>
        <translation>您確定要永久刪除此文件嗎？</translation>
    </message>
    <message>
        <source>You cannot restore it any longer</source>
        <translation>刪除後不可復原</translation>
    </message>
    <message>
        <source>Are you sure you want to permanently delete %1 files?</source>
        <translation>您確定要永久刪除這%1個文件嗎？</translation>
    </message>
    <message>
        <source>You cannot restore them any longer</source>
        <translation>刪除後不可復原</translation>
    </message>
    <message>
        <source>Are you sure you want to delete this file locally?</source>
        <translation>您確定要從本機刪除此文件嗎？</translation>
    </message>
    <message>
        <source>You can restore it in the trash</source>
        <translation>您可以在“最近刪除”中進行復原</translation>
    </message>
    <message>
        <source>Are you sure you want to delete %1 files locally?</source>
        <translation>您確定要從本機刪除這%1個文件嗎？</translation>
    </message>
    <message>
        <source>You can restore them in the trash</source>
        <translation>您可以在“最近刪除”中進行復原</translation>
    </message>
</context>
<context>
    <name>ImgInfoDialog</name>
    <message>
        <source>Basic info</source>
        <translation>基本資訊</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>詳細資訊</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>圖片訊息</translation>
    </message>
</context>
<context>
    <name>ImportTimeLineView</name>
    <message>
        <source>Import</source>
        <translation>匯入照片</translation>
    </message>
    <message>
        <source>1 photo</source>
        <translation>共1張照片</translation>
    </message>
    <message>
        <source>1 video</source>
        <translation>共1個影片</translation>
    </message>
    <message numerus="yes">
        <source>%n photos</source>
        <translation>
            <numerusform>共%n張照片</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n videos</source>
        <translation>
            <numerusform>共%n個影片</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n items</source>
        <translation>
            <numerusform>共%n項</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>ImportView</name>
    <message>
        <source>Import Photos and Videos</source>
        <translation>匯入照片和影片</translation>
    </message>
    <message>
        <source>Or drag them here</source>
        <translation>您也可以拖拽照片和影片到此</translation>
    </message>
    <message>
        <source>All photos and videos</source>
        <translation>所有照片和影片</translation>
    </message>
    <message>
        <source>No photos or videos found</source>
        <translation>未發現照片或影片檔案</translation>
    </message>
</context>
<context>
    <name>LeftListView</name>
    <message>
        <source>Slide show</source>
        <translation>幻燈片秀</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>重新命名</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>匯出</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>刪除</translation>
    </message>
    <message>
        <source>Device</source>
        <translation>裝置</translation>
    </message>
    <message>
        <source>Gallery</source>
        <translation>照片庫</translation>
    </message>
    <message>
        <source>Albums</source>
        <translation>相簿</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>建立相簿</translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <source>Album is a fashion manager for viewing and organizing photos and videos.</source>
        <translation>相冊是一款可多種方式瀏覽、整理照片和影片的管理工具。</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Photos</source>
        <translation>照片</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>全螢幕</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>說明</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>在檔案管理器中顯示</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>幻燈片秀</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>複製</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>設為桌布</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>順時針旋轉</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>逆時針旋轉</translation>
    </message>
    <message>
        <source>Previous</source>
        <translation>上一張</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>下一張</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>收藏</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>取消收藏</translation>
    </message>
    <message>
        <source>Rename album</source>
        <translation>重新命名相簿</translation>
    </message>
    <message>
        <source>Album “%1” removed</source>
        <translation>已成功刪除「%1」相簿</translation>
    </message>
    <message>
        <source>Successfully added to “%1”</source>
        <translation>成功新增至「%1」</translation>
    </message>
    <message>
        <source>Import successful</source>
        <translation>匯入成功</translation>
    </message>
    <message>
        <source>Import failed</source>
        <translation>匯入失敗</translation>
    </message>
    <message>
        <source>Export failed</source>
        <translation>匯出失敗</translation>
    </message>
    <message>
        <source>Export successful</source>
        <translation>匯出成功</translation>
    </message>
    <message>
        <source>All Photos</source>
        <translation>所有照片</translation>
    </message>
    <message>
        <source>Timelines</source>
        <translation>時間軸</translation>
    </message>
    <message>
        <source>Albums</source>
        <translation>相簿</translation>
    </message>
    <message>
        <source>Exit fullscreen/slideshow</source>
        <translation>退出全螢幕或幻燈片秀</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>顯示快捷鍵</translation>
    </message>
    <message>
        <source>View</source>
        <translation>查看</translation>
    </message>
    <message>
        <source>Select all</source>
        <translation>全選</translation>
    </message>
    <message>
        <source>Zoom in</source>
        <translation>放大</translation>
    </message>
    <message>
        <source>Zoom out</source>
        <translation>縮小</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>新增相簿</translation>
    </message>
    <message>
        <source>Page up</source>
        <translation>往上一頁</translation>
    </message>
    <message>
        <source>Page down</source>
        <translation>往下一頁</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>設定</translation>
    </message>
    <message>
        <source>Importing...</source>
        <translation>正在匯入...</translation>
    </message>
    <message>
        <source>All photos and videos</source>
        <translation>所有照片和影片</translation>
    </message>
    <message>
        <source>Import Photos and Videos</source>
        <translation>匯入照片和影片</translation>
    </message>
    <message>
        <source>No photos or videos found</source>
        <translation>未發現照片或影片檔案</translation>
    </message>
    <message>
        <source>Export photos</source>
        <translation>匯出照片</translation>
    </message>
    <message>
        <source>Import photos/videos</source>
        <translation>匯入照片和影片</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>刪除</translation>
    </message>
    <message>
        <source>Photo/Video info</source>
        <translation>照片/影片訊息</translation>
    </message>
    <message>
        <source>Import photos and videos</source>
        <translation>匯入照片和影片</translation>
    </message>
    <message>
        <source>Import folders</source>
        <translation>從資料夾匯入</translation>
    </message>
    <message>
        <source>Import interrupted</source>
        <translation>匯入中斷</translation>
    </message>
    <message>
        <source>Cannot add this path, please try another one</source>
        <translation>不支援此路徑，請嘗試其他路徑</translation>
    </message>
    <message>
        <source>The path already exists</source>
        <translation>路徑已存在</translation>
    </message>
    <message>
        <source>Failed to restore %1 files: file name too long</source>
        <translation>%1個文件復原失敗，檔案名過長</translation>
    </message>
    <message>
        <source>Classifying...</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MetadataName</name>
    <message>
        <source>Flash</source>
        <translation>播放</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>文件類型</translation>
    </message>
    <message>
        <source>File size</source>
        <translation>檔案大小</translation>
    </message>
    <message>
        <source>Dimensions</source>
        <translation>照片尺寸</translation>
    </message>
    <message>
        <source>Date captured</source>
        <translation>拍攝日期</translation>
    </message>
    <message>
        <source>Date modified</source>
        <translation>修改日期</translation>
    </message>
    <message>
        <source>Exposure mode</source>
        <translation>曝光模式</translation>
    </message>
    <message>
        <source>Exposure program</source>
        <translation>曝光模式</translation>
    </message>
    <message>
        <source>Exposure time</source>
        <translation>曝光時間</translation>
    </message>
    <message>
        <source>Aperture</source>
        <translation>光圈大小</translation>
    </message>
    <message>
        <source>Focal length</source>
        <translation>焦距</translation>
    </message>
    <message>
        <source>ISO</source>
        <translation>ISO感光度</translation>
    </message>
    <message>
        <source>Max aperture</source>
        <translation>最大光圈值</translation>
    </message>
    <message>
        <source>Metering mode</source>
        <translation>測光模式</translation>
    </message>
    <message>
        <source>White balance</source>
        <translation>白平衡</translation>
    </message>
    <message>
        <source>Flash compensation</source>
        <translation>閃光燈補償</translation>
    </message>
    <message>
        <source>Camera model</source>
        <translation>相機型號</translation>
    </message>
    <message>
        <source>Lens model</source>
        <translation>鏡頭型號</translation>
    </message>
    <message>
        <source>Colorspace</source>
        <translation>顏色空間</translation>
    </message>
    <message>
        <source>Tag</source>
        <translation>標記</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>名稱</translation>
    </message>
</context>
<context>
    <name>NoResultWidget</name>
    <message>
        <source>No results</source>
        <translation>無結果</translation>
    </message>
</context>
<context>
    <name>PathManager</name>
    <message>
        <source>System Disk</source>
        <translation>系統盤</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Select</source>
        <translation>選擇</translation>
    </message>
    <message>
        <source>Unselect</source>
        <translation>取消選擇</translation>
    </message>
    <message>
        <source>%1/%2/%3</source>
        <translation>%1年%2月%3日</translation>
    </message>
    <message>
        <source>Imported on</source>
        <translation>匯入於</translation>
    </message>
    <message>
        <source> %1-%2-%3 %4</source>
        <translation>%1年%2月%3日 %4</translation>
    </message>
    <message>
        <source>Imported on </source>
        <translation>匯入於</translation>
    </message>
    <message>
        <source>Select All</source>
        <translation>全選</translation>
    </message>
    <message>
        <source>Unselect All</source>
        <translation>取消全選</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>取消</translation>
    </message>
    <message>
        <source>Restore</source>
        <translation>復原</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>刪除</translation>
    </message>
    <message>
        <source>All</source>
        <translation>所有項目</translation>
    </message>
    <message>
        <source>Photos</source>
        <translation>照片</translation>
    </message>
    <message>
        <source>Videos</source>
        <translation>影片</translation>
    </message>
    <message>
        <source>No results</source>
        <translation>無結果</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>收藏</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>逆時針旋轉</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>順時針旋轉</translation>
    </message>
    <message>
        <source>Importing...</source>
        <translation>正在匯入，請稍候…</translation>
    </message>
    <message>
        <source>%1/%2 items imported</source>
        <translation>已匯入%1/%2項</translation>
    </message>
    <message>
        <source>%1/%2 items deleted</source>
        <translation>已刪除%1/%2項</translation>
    </message>
    <message>
        <source>%1 items imported, %2 items failed</source>
        <translation>%1個項目匯入成功，%2個項目匯入失敗</translation>
    </message>
    <message>
        <source>1 photo selected</source>
        <translation>已選擇1張照片</translation>
    </message>
    <message>
        <source>1 video selected</source>
        <translation>已選擇1個影片</translation>
    </message>
    <message>
        <source>The photo/video already exists</source>
        <translation>照片/影片已存在</translation>
    </message>
    <message numerus="yes">
        <source>%n photos selected</source>
        <translation>
            <numerusform>已選擇%n張照片</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n videos selected</source>
        <translation>
            <numerusform>已選擇%n個影片</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n items selected</source>
        <translation>
            <numerusform>已選擇%n項</numerusform>
        </translation>
    </message>
    <message>
        <source>%1 items imported, %2 items exist already</source>
        <translation>%1個項目匯入成功，%2個項目已存在</translation>
    </message>
    <message>
        <source>%1/%2 items classifyed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Scenery</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Food</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Humans</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Animals</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Scene</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Plants</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Items</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Other</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SearchView</name>
    <message>
        <source>No search results</source>
        <translation>無搜尋結果</translation>
    </message>
    <message>
        <source>Slide Show</source>
        <translation>幻燈片秀</translation>
    </message>
    <message>
        <source>Search results</source>
        <translation>搜尋結果</translation>
    </message>
    <message>
        <source>1 photo found</source>
        <translation>共找到1張照片</translation>
    </message>
    <message numerus="yes">
        <source>%n videos found</source>
        <translation>
            <numerusform>共找到%n個影片</numerusform>
        </translation>
    </message>
    <message>
        <source>1 video found</source>
        <translation>共找到1個影片</translation>
    </message>
    <message numerus="yes">
        <source>%n items found</source>
        <translation>
            <numerusform>共找到%n項</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n photos found</source>
        <translation>
            <numerusform>共找到%n張照片</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>StatusBar</name>
    <message>
        <source>1 photo</source>
        <translation>1張照片</translation>
    </message>
    <message>
        <source>1 video</source>
        <translation>1個影片</translation>
    </message>
    <message numerus="yes">
        <source>%n photos</source>
        <translation>
            <numerusform>%n張照片</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n videos</source>
        <translation>
            <numerusform>%n個影片</numerusform>
        </translation>
    </message>
    <message>
        <source>Importing: %1</source>
        <translation>正在匯入：%1</translation>
    </message>
    <message>
        <source>Exporting: %1</source>
        <translation>正在匯出：%1</translation>
    </message>
</context>
<context>
    <name>ThumbnailListView</name>
    <message>
        <source>View</source>
        <translation>查看</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>全螢幕</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>匯出</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>收藏</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>取消收藏</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>順時針旋轉</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>逆時針旋轉</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>在檔案管理器中顯示</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>設為桌布</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>刪除</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>幻燈片秀</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>複製</translation>
    </message>
    <message>
        <source>Photo info</source>
        <translation>照片訊息</translation>
    </message>
    <message>
        <source>Add to album</source>
        <translation>添加到相簿</translation>
    </message>
    <message>
        <source>Remove from album</source>
        <translation>從相簿中移除</translation>
    </message>
    <message>
        <source>Restore</source>
        <translation>復原</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>建立相簿</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>列印</translation>
    </message>
    <message>
        <source>Video info</source>
        <translation>影片訊息</translation>
    </message>
    <message>
        <source>days</source>
        <translation>天</translation>
    </message>
</context>
<context>
    <name>TimeLineView</name>
    <message>
        <source>1 photo</source>
        <translation>共1張照片</translation>
    </message>
    <message>
        <source>1 video</source>
        <translation>共1個影片</translation>
    </message>
    <message numerus="yes">
        <source>%n photos</source>
        <translation>
            <numerusform>共%n張照片</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n videos</source>
        <translation>
            <numerusform>共%n個影片</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n items</source>
        <translation>
            <numerusform>共%n項</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>VideoInfoDialog</name>
    <message>
        <source>Basic info</source>
        <translation>基本資訊</translation>
    </message>
    <message>
        <source>Codec info</source>
        <translation>編碼訊息</translation>
    </message>
    <message>
        <source>Audio info</source>
        <translation>音軌訊息</translation>
    </message>
    <message>
        <source>Video CodecID</source>
        <translation>影片軌訊息</translation>
    </message>
    <message>
        <source>Video CodeRate</source>
        <translation>影片碼率</translation>
    </message>
    <message>
        <source>FPS</source>
        <translation>影片幀率</translation>
    </message>
    <message>
        <source>Proportion</source>
        <translation>顯示比例</translation>
    </message>
    <message>
        <source>Resolution</source>
        <translation>解析度</translation>
    </message>
    <message>
        <source>Audio CodecID</source>
        <translation>編碼樣式</translation>
    </message>
    <message>
        <source>Audio CodeRate</source>
        <translation>編碼碼率</translation>
    </message>
    <message>
        <source>Audio digit</source>
        <translation>音訊位數</translation>
    </message>
    <message>
        <source>Channels</source>
        <translation>聲道數</translation>
    </message>
    <message>
        <source>Channel</source>
        <translation>聲道</translation>
    </message>
    <message>
        <source>Sampling</source>
        <translation>採樣數</translation>
    </message>
    <message>
        <source>Date modified</source>
        <translation>修改日期</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>文件類型</translation>
    </message>
    <message>
        <source>File size</source>
        <translation>檔案大小</translation>
    </message>
    <message>
        <source>Duration</source>
        <translation>時長</translation>
    </message>
    <message>
        <source>Path</source>
        <translation>文件路徑</translation>
    </message>
    <message>
        <source>Video info</source>
        <translation>影片訊息</translation>
    </message>
    <message>
        <source>Date captured</source>
        <translation>拍攝日期</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>名稱</translation>
    </message>
</context>
</TS>
